==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/ContentLinkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.ContentLinkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Definition of the content link.
 * @property contentHash Gets or sets the hash.
 * @property uri Gets or sets the uri of the runbook content.
 * @property version Gets or sets the version of the content.
 */
public data class ContentLinkArgs(
    public val contentHash: Output<ContentHashArgs>? = null,
    public val uri: Output<String>? = null,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.ContentLinkArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.ContentLinkArgs =
        com.pulumi.azurenative.automation.inputs.ContentLinkArgs.builder()
            .contentHash(contentHash?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .uri(uri?.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ContentLinkArgs].
 */
@PulumiTagMarker
public class ContentLinkArgsBuilder internal constructor() {
    private var contentHash: Output<ContentHashArgs>? = null

    private var uri: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value Gets or sets the hash.
     */
    @JvmName("qrkeftgdiquuqpqh")
    public suspend fun contentHash(`value`: Output<ContentHashArgs>) {
        this.contentHash = value
    }

    /**
     * @param value Gets or sets the uri of the runbook content.
     */
    @JvmName("wdnbhqxyvsuayqbu")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value Gets or sets the version of the content.
     */
    @JvmName("dbhcekhjuoqvsfxb")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value Gets or sets the hash.
     */
    @JvmName("ksoichgmfrwfkobp")
    public suspend fun contentHash(`value`: ContentHashArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentHash = mapped
    }

    /**
     * @param argument Gets or sets the hash.
     */
    @JvmName("afuvofbmmgqtnqtb")
    public suspend fun contentHash(argument: suspend ContentHashArgsBuilder.() -> Unit) {
        val toBeMapped = ContentHashArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.contentHash = mapped
    }

    /**
     * @param value Gets or sets the uri of the runbook content.
     */
    @JvmName("eieyqfuaqgvlytbr")
    public suspend fun uri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    /**
     * @param value Gets or sets the version of the content.
     */
    @JvmName("yjhcvthanjvugday")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): ContentLinkArgs = ContentLinkArgs(
        contentHash = contentHash,
        uri = uri,
        version = version,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/ContentLinkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.ContentLinkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Definition of the content link.
 * @property contentHash Gets or sets the hash.
 * @property uri Gets or sets the uri of the runbook content.
 * @property version Gets or sets the version of the content.
 */
public data class ContentLinkArgs(
    public val contentHash: Output<ContentHashArgs>? = null,
    public val uri: Output<String>? = null,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.ContentLinkArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.ContentLinkArgs =
        com.pulumi.azurenative.automation.inputs.ContentLinkArgs.builder()
            .contentHash(contentHash?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .uri(uri?.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ContentLinkArgs].
 */
@PulumiTagMarker
public class ContentLinkArgsBuilder internal constructor() {
    private var contentHash: Output<ContentHashArgs>? = null

    private var uri: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value Gets or sets the hash.
     */
    @JvmName("bswmpkdqpulfqpaw")
    public suspend fun contentHash(`value`: Output<ContentHashArgs>) {
        this.contentHash = value
    }

    /**
     * @param value Gets or sets the uri of the runbook content.
     */
    @JvmName("guojfslblruiblgn")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value Gets or sets the version of the content.
     */
    @JvmName("mkrjvkieoounimab")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value Gets or sets the hash.
     */
    @JvmName("fjpytuqmfokxpexh")
    public suspend fun contentHash(`value`: ContentHashArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentHash = mapped
    }

    /**
     * @param argument Gets or sets the hash.
     */
    @JvmName("mupxytarowvadkxp")
    public suspend fun contentHash(argument: suspend ContentHashArgsBuilder.() -> Unit) {
        val toBeMapped = ContentHashArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.contentHash = mapped
    }

    /**
     * @param value Gets or sets the uri of the runbook content.
     */
    @JvmName("cfdfdfddhanlnxly")
    public suspend fun uri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    /**
     * @param value Gets or sets the version of the content.
     */
    @JvmName("lrtqikdexafumktk")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): ContentLinkArgs = ContentLinkArgs(
        contentHash = contentHash,
        uri = uri,
        version = version,
    )
}
